﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using CTNet;

namespace ChkBoxCtrl
{
    public partial class Form1 : Form
    {
        // This file holds all of the global vars used by the Checkbox Control application.

        // This tells us if this app was launched from an editor such as Visual Studio Code.
        public static bool editorLaunch = false;

        /*
         * These are used to keep an eye on the box formats between the
         * associated lists as the user can end up setting both but with
         * different formats. For ex., they can launch this tool from the
         * editor with old format boxes in the clipboard and then use the
         * menu button to read an XML file that has new format boxes, a
         * clash of formats.
         */
        public enum boxFormat { oldFormat, newFormat, notSet };

        public boxFormat boxListFormat = boxFormat.notSet;
        public boxFormat setListFormat = boxFormat.notSet;

        /*
         * These are Visual Studio Code related:
         * 
         * The .calctool port file path is initialized in the
         * VSCFileInfo class constructor.
         */
        public CTClient ctClient = null;
        public static VSCFileInfo vscFileInfo = null;
        public bool isConnected = false;

        /*
         * This is the currently selected 'Check Box Sets'
         * index. Used when receiving checkbox selections
         * from Calc Helper.
         */
        public int boxSetsIndex = -1;

        // This is set to our work directory, the same path on all computers. 
        public static string curDir = "C:\\temp\\work";

        /*
         * Where the method file [the method itself] is stored:
         * This is the production path:
         */
        string methodPath = @"\\PDC\FormsProgramming\Shared Code\";

        // This path is for testing.
        //string methodPath = @"\\PDC\FormsProgramming\Shared Code\Calc Tool Test\";

        // This path is for Home testing.
        //string methodPath = @"C:\\temp\\work\\";

        string methodFileName = "ChkBoxCtrlMethod.js";
        string methodName = "checkBoxCtrl";

        /*
         * This string holds generated check box control code: method body with method invocation;
         * check box sets.
         * It is also used to store check box sets retrieved from (either the clipboard) or (the .js
         * file text selection when launched from an editor).
         */
        string chkBoxCtrlStr = "";

        // The title of our Form.
        string wndwTitle = "CHECKBOX CONTROL";

        string version = "3.0";

        /*
         * This dictionary holds the 'XML Check Boxes' list boxes
         * as the Key and their associated page number as the Value.
         */
        public Dictionary<string, int> boxPageDict = new Dictionary<string, int>();

        /*
         * This list holds the 'Check Box Sets' indices where we discovered a duplicate box while
         * Updating the selected set.
         */
        List<int> dupIndxList = new List<int>();

        /*
         * This list holds the 'Set Manipulation' boxes which are present in the 'Check Box Sets'
         * in locations other than the currently selected set.
         */
        List<string> dupManipList = new List<string>();

        /*
         * This list holds the 'Check Box Sets' indices where we filtered down to a 1 box set.
         * This is the only time we allow a one box set. The user will need to either select
         * these sets and update them with one or more boxes, or will need to delete them.
         */
        List<int> oneBoxIndxList = new List<int>();

        /*
         * The Mode menu button is disabled if this application is not launched from an editor.
         * We use the mode to automatically close the application after a Copy To Clipboard
         * button has been clicked.
         * 
         * This application will be set to editChkBoxSets mode when check box sets are
         * detected in the clipboard upon editor launch - the sets are in a separate location
         * in a document's script file, so someone must be about to edit a pre-existing check
         * box set.
         * 
         * This application will be set to addChkBoxCtrl mode when check box sets are
         * not detected in the clipboard upon editor launch, the assumption being that they
         * want to add check box control to a document's script file.
         * 
         * The user will be able to change the mode when launching from an editor in case the
         * above assumptions are not valid.
         */
        public enum LaunchMode { disabled, editChkBoxSets, addChkBoxCtrl };
        public LaunchMode launchMode = LaunchMode.disabled;

        /*
         * These are the Mode 'clicked' vars used in determing when to automatically
         * shut the application down after a copy to clipboard button has been clicked.
         * We only deal with these when we launched from the code editor and we are in
         * 'Add Check Box Control' mode - we need to know if the copy to clipboard
         * button they just clicked was the last one to be clicked. In this situation we
         * will also color the one button that was first clicked so the user can remember
         * who was clicked, realizing that the app will close when they click the uncolored
         * copy to clipboard button.
         */
        bool copySetsClicked = false;
        bool copyMethClicked = false;

        /*
         The 'Button Help' area:
        */
        string helpText = "Click On A Button/List To View Help";
        bool showHelp = false;

        /*
         * This serves 2 functions depending on whether
         * Checkbox Control is receiving checkbox selections
         * from Calc Helper.
         */
        bool xmlFiltBtnEnabled;
    }
}